%global with_debug 1
%global with_check 0

%bcond_without varlink
%global gogenerate go generate

%if 0%{?with_debug}
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%if 0%{?rhel} > 7 && ! 0%{?fedora}
%define gobuild(o:) \
go build -buildmode pie -compiler gc -tags="rpm_crashtraceback libtrust_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%endif

%global branch v1.9
%global provider github
%global provider_tld com
%global project containers
%global repo libpod
# https://github.com/containers/libpod
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path %{provider_prefix}
%global git0 https://%{provider}.%{provider_tld}/%{project}/%{repo}
%global commit0 4284fd42550787778e39f50fdddad57f276e12d3
%global shortcommit0 %(c=%{commit0}; echo ${c:0:7})

Name: podman
Version: 1.9.3
Release: 5.rhaos4.6%{?dist}
Summary: Manage Pods, Containers and Container Images
License: ASL 2.0
URL: https://%{name}.io/
%if 0%{?branch:1}
Source0: https://%{import_path}/tarball/%{commit0}/%{branch}-%{shortcommit0}.tar.gz
%else
Source0: https://%{import_path}/archive/%{commit0}/%{name}-%{version}-%{shortcommit0}.tar.gz
%endif
Provides: %{name}-manpages = %{version}-%{release}
Obsoletes: %{name}-manpages < %{version}-%{release}
BuildRequires: golang >= 1.12.12-4
BuildRequires: glib2-devel
BuildRequires: glibc-devel
BuildRequires: glibc-static
BuildRequires: git
BuildRequires: go-md2man
BuildRequires: gpgme-devel
BuildRequires: libassuan-devel
BuildRequires: libgpg-error-devel
BuildRequires: libseccomp-devel
BuildRequires: libselinux-devel
BuildRequires: ostree-devel
BuildRequires: pkgconfig
BuildRequires: make
BuildRequires: systemd
BuildRequires: systemd-devel
Requires: containers-common >= 0.1.29-3
Requires: containernetworking-plugins >= 0.8.1-1
Requires: iptables
Requires: nftables
Obsoletes: oci-systemd-hook < 1
Requires: libseccomp >= 2.4.1
Requires: conmon
Recommends: container-selinux
Requires: slirp4netns >= 0.4.0-1
Requires: runc >= 1.0.0-57
Requires: fuse-overlayfs
Requires: libvarlink

%description
%{name} (Pod Manager) is a fully featured container engine that is a simple
daemonless tool.  %{name} provides a Docker-CLI comparable command line that
eases the transition from other container engines and allows the management of
pods, containers and images.  Simply put: alias docker=%{name}.
Most %{name} commands can be run as a regular user, without requiring
additional privileges.

%{name} uses Buildah(1) internally to create container images.
Both tools share image (not container) storage, hence each can use or
manipulate images (but not containers) created by the other.

%{summary}
%{repo} Simple management tool for pods, containers and images

%package docker
Summary: Emulate Docker CLI using %{name}
BuildArch: noarch
Requires: %{name} = %{version}-%{release}
Conflicts: docker
Conflicts: docker-latest
Conflicts: docker-ce
Conflicts: docker-ee
Conflicts: moby-engine

%description docker
This package installs a script named docker that emulates the Docker CLI by
executes %{name} commands, it also creates links between all Docker CLI man
pages and %{name}.

%package remote
Summary: (Experimental) Remote client for managing %{name} containers

%description remote
Remote client for managing %{name} containers.

This experimental remote client is under heavy development. Please do not
run %{name}-remote in production.

%{name}-remote uses the varlink connection to connect to a %{name} client to
manage pods, containers and container images. %{name}-remote supports ssh
connections as well.

%package tests
Summary: Tests for %{name}
Requires: %{name} = %{version}-%{release}
#Requires: bats  (which RHEL8 doesn't have. If it ever does, un-comment this)
Requires: jq

%description tests
%{summary}

This package contains system tests for %{name}

%prep
%if 0%{?branch:1}
%autosetup -Sgit -n containers-%{name}-%{shortcommit0}
%else
%autosetup -Sgit -n %{name}-%{commit0}
%endif

sed -i 's/install.bin: podman/install.bin:/' Makefile
sed -i 's/install.man: docs/install.man:/' Makefile
sed -i 's/install.remote: podman-remote/install.remote:/' Makefile
mv pkg/hooks/README.md pkg/hooks/README-hooks.md

# this is shipped by skopeo: containers-common subpackage
rm -rf docs/source/markdown/containers-mounts.conf.5.md

%build
export GO111MODULE=off
export GOPATH=$(pwd):$(pwd)/_build

mkdir -p $(pwd)/_build
pushd $(pwd)/_build
mkdir -p src/%{provider}.%{provider_tld}/%{project}
ln -s ../../../../ src/%{import_path}
popd
ln -s vendor src

rm -rf vendor/github.com/containers/storage/drivers/register/register_btrfs.go
%gogenerate ./pkg/varlink/...

# build %%{name}
export BUILDTAGS="varlink systemd selinux seccomp btrfs_noversion exclude_graphdriver_devicemapper $(hack/libdm_tag.sh)"
%gobuild -o bin/%{name} %{import_path}/cmd/%{name}

# build %%{name}-remote
export BUILDTAGS="remoteclient $BUILDTAGS"
%gobuild -o bin/%{name}-remote %{import_path}/cmd/%{name}

%{__make} docs
./docs/dckrman.sh ./docs/build/man/*

%install
install -dp %{buildroot}%{_unitdir}
PODMAN_VERSION=%{version} %{__make} PREFIX=%{buildroot}%{_prefix} ETCDIR=%{buildroot}%{_sysconfdir} \
        install.bin \
        install.remote \
        install.man \
        install.cni \
        install.systemd \
        install.completions \
        install.docker

# install libpod.conf
install -dp %{buildroot}%{_datadir}/containers
install -m 644 %{repo}.conf %{buildroot}%{_datadir}/containers

# install docker-docs
install -dp %{buildroot}%{_mandir}/man1
install -m 644 docs/build/man/docker*.1 -t %{buildroot}%{_mandir}/man1

# install docker symlink
install -m 755 docker %{buildroot}%{_bindir}

# install test stuff
ln -s ./ ./vendor/src # ./vendor/src -> ./vendor
install -d -p %{buildroot}/%{_datadir}/%{name}/test/system
cp -pav test/system %{buildroot}/%{_datadir}/%{name}/test/

# do not include docker and podman-remote man pages in main package
for file in `find %{buildroot}%{_mandir}/man[15] -type f | sed "s,%{buildroot},," | grep -v -e remote -e docker`; do
    echo "$file*" >> podman.file-list
done

%check
%if 0%{?with_check}
# Since we aren't packaging up the vendor directory we need to link
# back to it somehow. Hack it up so that we can add the vendor
# directory from BUILD dir as a gopath to be searched when executing
# tests from the BUILDROOT dir.
ln -s ./ ./vendor/src # ./vendor/src -> ./vendor

export GOPATH=%{buildroot}/%{gopath}:$(pwd)/vendor:%{gopath}

%if ! 0%{?gotest:1}
%global gotest go test
%endif

%gotest %{import_path}/cmd/%{name}
%gotest %{import_path}/libkpod
%gotest %{import_path}/libpod
%gotest %{import_path}/pkg/registrar
%endif

%triggerpostun -- %{name} < 1.1
%{_bindir}/%{name} system renumber
exit 0

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%files -f podman.file-list
%license LICENSE
%doc README.md CONTRIBUTING.md pkg/hooks/README-hooks.md install.md transfer.md
%{_bindir}/%{name}
%{_datadir}/bash-completion/completions/*
# By "owning" the site-functions dir, we don't need to Require zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}
%config(noreplace) %{_sysconfdir}/cni/net.d/87-%{name}-bridge.conflist
%{_datadir}/containers/%{repo}.conf
%{_unitdir}/io.%{name}.service
%{_unitdir}/io.%{name}.socket
%{_userunitdir}/io.%{name}.service
%{_userunitdir}/io.%{name}.socket
%{_usr}/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}.socket
%{_userunitdir}/%{name}.service
%{_userunitdir}/%{name}.socket

%files docker
%{_bindir}/docker
%{_mandir}/man1/docker*.1*
%{_usr}/lib/tmpfiles.d/%{name}-docker.conf

%files remote
%{_bindir}/%{name}-remote
%{_mandir}/man1/%{name}-remote*.1*
%{_mandir}/man5/%{name}-remote*.5*

%files tests
%license LICENSE
%{_datadir}/%{name}/test

%changelog
* Wed Apr 20 2022 Jindrich Novy <jnovy@redhat.com> - 1.9.3-5.rhaos4.6
- fix CVE-2022-1227
- Resolves: #2072265

* Mon Oct 11 2021 Jindrich Novy <jnovy@redhat.com> - 1.9.3-4.rhaos4.6
- revert the previous change
- Related: #2010432

* Mon Oct 11 2021 Jindrich Novy <jnovy@redhat.com> - 3.4.1-1.rhaos4.6
- update to the latest content of https://github.com/containers/podman/tree/v3.4
  (https://github.com/containers/podman/commit/c15c154)
- Related: #2010432

* Wed Sep 23 2020 Jindrich Novy <jnovy@redhat.com> - 1.9.3-3.rhaos4.6
- fix "CVE-2020-14370 podman: environment variables leak between containers when started via Varlink or Docker-compatible REST API [openshift-4]"
- Resolves: #1876286

* Mon Aug 03 2020 Jindrich Novy <jnovy@redhat.com> - 1.9.3-2.rhaos4.6
- fix "CVE-2020-14040 podman: golang.org/x/text: possibility to trigger an infinite loop in encoding/unicode could lead to crash [openshift-4]"
- Resolves: #1855699

* Thu Jun 18 2020 Jindrich Novy <jnovy@redhat.com> - 1.9.3-1.rhaos4.6
- introduce podman-1.9.3 to rhaos-4.6
- Resolves: #1846213
